@@ -111,9 +111,10 @@ class Lattice:
         new_vectors = np.array(args).T
         self.__XA[0:len(args[0]), 0:len(args)] = new_vectors
         if np.isclose(np.linalg.det(self.__XA), 0):
+            bad_XA = self.__XA
             self.__XA = old_XA
-            raise LinearDependenceError
-
+            raise LinearDependenceError("{}".format(bad_XA))
+        
         if atoms_behaviour == Unit.Angstrom:
             for i, a in enumerate(self.__atoms):
                 self.__atoms[i] = Atom(a.element,
@@ -123,6 +124,29 @@ class Lattice:
 
         return self
 
+    def rotate(self, theta: float):
+        """
+        Rotates the lattice around the origin.
+
+        Parameters
+        ----------
+        theta : float
+            Angle in radians
+
+        Returns
+        -------
+        Lattice
+            for chaining
+        """
+        # TODO: tests
+        vecs = self.vectors()
+        v1 = vecs[0][0:2]
+        v2 = vecs[1][0:2]
+        v1 = rotate(v1, theta)
+        v2 = rotate(v2, theta)
+        self.set_vectors(v1, v2, atoms_behaviour=Unit.Crystal)
+        return self
+
     def vectors(self) -> List[VectorNumpy]:
         """
         Lists lattice vectors
@@ -316,6 +340,11 @@ class Lattice:
                 atomic_species[a.element] = [a]
                 names.append(a.element)
 
+        # New in VASP December 2019 – atomic species names
+        for name in names:
+            s += "{} ".format(name)
+        s = s[:-1] + '\n'
+
         for name in names:
             atoms_list = atomic_species[name]
             s += "{} ".format(len(atoms_list))
@@ -356,9 +385,6 @@ class Lattice:
             print(s)
 
         if not silent:
-            print("Note: The order of the atomic species in this generated " +
-                  "POSCAR file is as follows:\n" + " ".join(names))
-
             # magmom
             magmom_str = " ".join([((str(x[1]) + "*" if x[1] > 1 else "")
                                     + str(x[0])) for x in magmom])
@@ -439,13 +465,21 @@ class Lattice:
         self.__atoms = []
         self.add_atoms(atoms)
 
-    def draw(self, ax=None):
+    def draw(self, ax=None, cell_coords=None, scatter_kwargs=None, border_kwargs=None):
         """
         Requires matplotlib. Creates an image of the lattice elementary cell
         as a matplotlib plot.
 
         Parameters
         ----------
+        cell_coords : List[Vector2D], optional
+            Each point in `cell_coords` is an offset in Lattice vector basis.
+            For each of those offsets, all atoms in the cell will be drawn with
+            their positions moved by this offset. Use integer values to get
+            consistent drawings. Note: You can use things like [(-0.5, -0.5),
+             (-0.5, 0.5), (0.5, -0.5), (0.5, 0.5)] to get a picture of a translated
+             elementary cell.
+            Default: [(0, 0)] (draws just one elementary cell)
         ax : matplotlib axes.Axes object, optional
             If given, will draw the elementary cell to ax
 
@@ -458,6 +492,11 @@ class Lattice:
         Resulting axes has points labeled; use
         `ax.legend(loc='best')` to turn on the legend.
         """
+        if cell_coords is None:
+            cell_coords = [np.array([0, 0])]
+        else:
+            cell_coords = [np.array(pt) for pt in cell_coords]
+
         if ax is None:
             import matplotlib.pyplot as plt
             plt.clf()
@@ -465,6 +504,18 @@ class Lattice:
         else:
             fig = ax.figure
 
+        if scatter_kwargs is None:
+            scatter_kwargs = {
+                "marker": '.',
+                "s": 2
+            }
+        if border_kwargs is None:
+            border_kwargs = {
+                "linestyle": '--',
+                "color": (55 / 255, 126 / 255, 184 / 255),  # orig. "gray"
+                "linewidth": 2
+            }
+
         species = set()
         for a in self.atoms():
             species.add(a.element)
@@ -473,7 +524,7 @@ class Lattice:
         # A set of nice colours from ColorBrewer2.org
         colors = [
             (228 / 255, 26 / 255, 28 / 255),
-            (55 / 255, 126 / 255, 184 / 255),
+            #(55 / 255, 126 / 255, 184 / 255),
             (77 / 255, 175 / 255, 74 / 255),
             (152 / 255, 78 / 255, 163 / 255),
             (255 / 255, 127 / 255, 0 / 255),
@@ -488,21 +539,30 @@ class Lattice:
 
         for color, specie in zip(colors, species):
             atoms = [a for a in self.atoms() if a.element == specie]
-            ax.scatter([a.pos[0] for a in atoms],
-                       [a.pos[1] for a in atoms],
-                       marker='.',
-                       label=specie,
-                       color=color)
-            for a in atoms:
-                if a.spin[2] > 0:
-                    ax.annotate('↑', (a.pos[0], a.pos[1]))
-                elif a.spin[2] < 0:
-                    ax.annotate('↓', (a.pos[0], a.pos[1]))
+            positions = [a.pos for a in atoms]
+            v1, v2 = self.__XA[0:2, 0], self.__XA[0:2, 1]
+            for cell_coord in cell_coords:
+                positions_x = [p[0] + v1[0] * cell_coord[0] + v2[0] * cell_coord[1]
+                               for p in positions]
+                positions_y = [p[1] + v1[1] * cell_coord[0] + v2[1] * cell_coord[1]
+                               for p in positions]
+                ax.scatter(positions_x,
+                           positions_y,
+                           label=specie,
+                           color=color,
+                           **scatter_kwargs)
+
+                for a, px, py in zip(atoms, positions_x, positions_y):
+                    if a.spin[2] > 0:
+                        ax.annotate('↑', (px, py))
+                    elif a.spin[2] < 0:
+                        ax.annotate('↓', (px, py))
 
         # Draw cell boundary
         vecs = np.array([v[0:2] for v in self.vectors()[0:2]])
         pts = np.array([(0, 0), vecs[0], vecs[0] + vecs[1], vecs[1], (0, 0)]).T
-        ax.plot(pts[0], pts[1], '--', color="gray")
+
+        ax.plot(pts[0], pts[1], **border_kwargs)
 
         ax.set_aspect('equal', adjustable='box')
         return fig, ax
